@@ -2,6 +2,7 @@ import click
 from pprint import pprint
 from pathlib import Path
 from subprocess import run
+from importlib.metadata import version
 import yaml
 import toml
 import os
@@ -50,9 +51,7 @@ def cli():
 @cli.command()
 def version():
     "Print MWC version"
-    config = toml.loads(Path(__file__) / "pyproject.toml").read_text())
-    version = config['tool']['poetry']['version']
-    click.echo(address("MWC " + version, preformatted=True))
+    click.echo(address("MWC " + version('making-with-code-cli'), preformatted=True))
 
 @cli.command()
 @click.option("--yes", is_flag=True, help="Automatically answer 'yes' to setup prompts")
